@@ -2,12 +2,24 @@
 /**
  * @file autogen.h
  *
- *  Time-stamp:        "2012-04-07 09:45:02 bkorb"
- *
  *  Global header file for AutoGen
+ */
+/**
+ * @mainpage
+ * @section Introduction
+ * Autogen is a multi-component project.  There is the basic engine itself
+ * ("autogen"), a library ("libopts") and its support templates (collectively,
+ * "AutoOpts"), several support and utility programs ("columns", "getdefs" and
+ * "xml2ag"), *plus* several handy embedded utility templates.  They are all
+ * bundled together because they all require each other.  They each do completely
+ * separate things, but they each are not useful without the other.  Thus,
+ * they are bundled together.
  *
- *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
+ * @group autogen
+ * @{
+ */
+/*  This file is part of AutoGen.
+ *  AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -28,11 +40,27 @@
 #include "compat/unlocked-io.h"
 
 #include REGEX_HEADER
+#if !defined(__GNUC__)
+#define GCC_VERSION 0
+#elif ! defined(GCC_VERSION)
+#define GCC_VERSION (__GNUC__ * 10000 \
+                    + __GNUC_MINOR__ * 100 \
+                    + __GNUC_PATCHLEVEL__)
+#endif
+
+#if GCC_VERSION > 40400
+#pragma  GCC diagnostic push
+#pragma  GCC diagnostic ignored "-Wextra"
+#pragma  GCC diagnostic ignored "-Wconversion"
+#pragma  GCC diagnostic ignored "-Wsign-conversion"
+#pragma  GCC diagnostic ignored "-Wstrict-overflow"
+#endif
+
 #include <libguile/scmconfig.h>
-#if GUILE_VERSION < 107000
-# include <guile/gh.h>
-#else
-# include <libguile.h>
+#include <libguile.h>
+
+#if GCC_VERSION > 40400
+#pragma  GCC diagnostic pop
 #endif
 
 #include "ag-text.h"
@@ -41,6 +69,7 @@
 #include "autoopts/autoopts.h"
 #include "directive.h"
 #include "snprintfv/printf.h"
+#include "scribble.h"
 
 #define  LOG10_2to32  10  /* rounded up */
 
@@ -161,49 +190,55 @@ struct tlib_mark {
     unsigned short  tlm_cksum;      /* FUNCTION_CKSUM       */
 };
 
-/*
- *  Defines for conditional expressions.
- *  The first four are an enumeration that appear in the
- *  low four bits and the next-to-lowest four bits.
- *  "PRIMARY_TYPE" and "SECONDARY_TYPE" are masks for
- *  extracting this enumeration.  The rest are flags.
+/**
+ *  Defines for conditional expressions.  The first four are an enumeration
+ *  that appear in the low four bits and the next-to-lowest four bits.
+ *  "PRIMARY_TYPE" and "SECONDARY_TYPE" are masks for extracting this
+ *  enumeration.  The rest are flags.
  */
-#define EMIT_VALUE          0x0000  /* emit value of variable  */
-#define EMIT_EXPRESSION     0x0001  /* Emit Scheme result      */
-#define EMIT_SHELL          0x0002  /* emit shell output       */
-#define EMIT_STRING         0x0003  /* emit content of expr    */
-#define EMIT_PRIMARY_TYPE   0x0007
-#define EMIT_SECONDARY_TYPE 0x0070
-#define EMIT_SECONDARY_SHIFT     4
-#define EMIT_IF_ABSENT      0x0100
-#define EMIT_ALWAYS         0x0200  /* emit one of two exprs   */
-#define EMIT_FORMATTED      0x0400  /* format, if val present  */
-#define EMIT_NO_DEFINE      0x0800  /* don't get defined value */
+#define EMIT_VALUE          0x0000  //!< emit value of variable
+#define EMIT_EXPRESSION     0x0001  //!< Emit Scheme result
+#define EMIT_SHELL          0x0002  //!< emit shell output
+#define EMIT_STRING         0x0003  //!< emit content of expr
+#define EMIT_PRIMARY_TYPE   0x0007  //!< mask for primary emission type
+#define EMIT_SECONDARY_TYPE 0x0070  //!< mask for secondary emission type
+#define EMIT_SECONDARY_SHIFT     4  //!< bit offset for secondary type
+#define EMIT_IF_ABSENT      0x0100  //!< emit text when value non-existant
+#define EMIT_ALWAYS         0x0200  //!< emit one of two exprs
+#define EMIT_FORMATTED      0x0400  //!< format, if val present
+#define EMIT_NO_DEFINE      0x0800  //!< don't get defined value
 
+/**
+ * template macro descriptor.
+ */
 struct macro_desc {
-    mac_func_t    md_code;     /* Macro function           */
-    int           md_line;     /* of macro def             */
-    int           md_end_idx;  /* End of block macro       */
-    int           md_sib_idx;  /* Sibling macro (ELIF or SELECT) */
+    mac_func_t    md_code;      //!< Macro function
+    int           md_line;      //!< of macro def
+    int           md_end_idx;   //!< End of block macro
+    int           md_sib_idx;   //!< Sibling macro (ELIF or SELECT)
 
-    uintptr_t     md_name_off; /* macro name (sometimes)   */
-    uintptr_t     md_txt_off;  /* associated text          */
-    uintptr_t     md_res;      /* some sort of result      */
-    void *        md_pvt;
+    uintptr_t     md_name_off;  //!< macro name (sometimes)
+    uintptr_t     md_txt_off;   //!< associated text
+    uintptr_t     md_res;       //!< some sort of result
+    void *        md_pvt;       //!< private data for particular macro
 };
 
+/**
+ * AutoGen template descriptor.
+ * A full template or a defined macro is managed with this structure.
+ */
 struct template_desc {
-    tlib_mark_t   td_magic;    /* TEMPLATE_MAGIC_MARKER    */
-    size_t        td_size;     /* Structure Size           */
-    char *        td_scan;     /* Next Pointer             */
-    int           td_mac_ct;   /* Count of Macros          */
-    char const *  td_file;     /* Name of template file    */
-    char *        td_name;     /* Defined Macro Name       */
-    char *        td_text;     /* offset of the text       */
+    tlib_mark_t   td_magic;     //!< TEMPLATE_MAGIC_MARKER
+    size_t        td_size;      //!< Structure Size
+    char *        td_scan;      //!< Next Pointer
+    int           td_mac_ct;    //!< Count of Macros
+    char const *  td_file;      //!< Name of template file
+    char *        td_name;      //!< Defined Macro Name
+    char *        td_text;      //!< base address of the text
     char          td_start_mac[MAX_SUFFIX_LEN];
     char          td_end_mac[  MAX_SUFFIX_LEN];
-    macro_t       td_macros[1]; /* Array of Macros          */
-/*  char          td_text[...];  * strings at end of macros */
+    macro_t       td_macros[1]; //!< Array of Macros
+//  char          td_text[...];  * strings are at end of macros
 };
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -292,6 +327,7 @@ struct for_state {
     char *        for_name;     //!< name of iterator (not allocated)
     bool          for_islast;   //!< true for last iteration
     bool          for_isfirst;  //!< true for first iteration
+    bool          for_not_found;//!< usually false, true with sparse arrays
     jmp_buf       for_env;      //!< long jump buffer (BREAK, CONTINUE)
 };
 
@@ -411,6 +447,7 @@ MODE char *         cgi_stderr       VALUE( NULL );
 
 MODE char const *   server_args[2]   VALUE( { NULL } );
 MODE char const *   shell_program    VALUE( MK_STR(CONFIG_SHELL) );
+MODE char const *   libguile_ver     VALUE( NULL );
 
 /*
  *  AutoGen definiton and template context
@@ -527,20 +564,27 @@ MODE v2c_t p2p VALUE( { NULL } );
 
 #include "proto.h"
 
-static inline SCM ag_eval(char const * pzStr)
+/**
+ * Evaluate a scheme expression, setting the file and line number from
+ * the file and line of the currently active macro.
+ *
+ * @param[in] str  the scheme expression
+ * @returns the SCM result.  That may be SCM_UNDEFINED.
+ */
+static inline SCM ag_eval(char const * str)
 {
     SCM res;
-    char const * pzSaveScheme = last_scm_cmd; /* Watch for nested calls */
-    last_scm_cmd = pzStr;
+    char const * sv = last_scm_cmd; /* Watch for nested calls */
+    last_scm_cmd = str;
 
     res = ag_scm_c_eval_string_from_file_line(
-        pzStr, current_tpl->td_file, cur_macro->md_line);
+        str, current_tpl->td_file, cur_macro->md_line);
 
-    last_scm_cmd = pzSaveScheme;
+    last_scm_cmd = sv;
     return res;
 }
 
-/*
+/**
  *  Extracted from guile-iface stuff.  Seems to be stable since for at least
  *  1.6.0 through 2.0.0.  1.4.x is thoroughly dead now (May, 2011).
  */
@@ -555,13 +599,15 @@ static inline SCM ag_eval(char const * pzStr)
 
 #define AG_SCM_CHAR_P(_c)            SCM_CHARP(_c)
 
-/*
+/**
  * Hide dummy functions from complexity measurement tools
  */
 #define HIDE_FN(_t)  _t
 
+#define LOCAL static
 #endif /* AUTOGEN_BUILD */
-/*
+/** @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
