@@ -4,10 +4,12 @@
  *
  *  This module evaluates macro expressions.
  *
- *  Time-stamp:        "2012-04-07 09:41:46 bkorb"
- *
+ * @addtogroup autogen
+ * @{
+ */
+/*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (c) 1992-2012 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -43,7 +45,7 @@ LOCAL char const *
 scm2display(SCM s)
 {
     static char  z[48];
-    char const * pzRes = z;
+    char const * res = z;
 
     switch (ag_scm_type_e(s)) {
     case GH_TYPE_BOOLEAN:
@@ -52,17 +54,17 @@ scm2display(SCM s)
 
     case GH_TYPE_STRING:
     case GH_TYPE_SYMBOL:
-        pzRes = ag_scm2zchars(s, "SCM Result");
+        res = ag_scm2zchars(s, "SCM Result");
         break;
 
     case GH_TYPE_CHAR:
-        z[0] = AG_SCM_CHAR(s); z[1] = NUL; break;
+        z[0] = (char)AG_SCM_CHAR(s); z[1] = NUL; break;
 
     case GH_TYPE_VECTOR:
-        pzRes = RESOLVE_SCM_VECTOR; break;
+        res = RESOLVE_SCM_VECTOR; break;
 
     case GH_TYPE_PAIR:
-        pzRes = RESOLVE_SCM_PAIR; break;
+        res = RESOLVE_SCM_PAIR; break;
 
     case GH_TYPE_NUMBER:
         snprintf(z, sizeof(z), RESOLVE_SCM_NUMBER, AG_SCM_TO_ULONG(s)); break;
@@ -77,27 +79,27 @@ scm2display(SCM s)
         break;
     }
 #else
-        pzRes = "** PROCEDURE **";
+        res = "** PROCEDURE **";
         break;
 #endif
 
     case GH_TYPE_LIST:
-        pzRes = RESOLVE_SCM_LIST; break;
+        res = RESOLVE_SCM_LIST; break;
 
     case GH_TYPE_INEXACT:
-        pzRes = RESOLVE_SCM_INEXACT; break;
+        res = RESOLVE_SCM_INEXACT; break;
 
     case GH_TYPE_EXACT:
-        pzRes = RESOLVE_SCM_EXACT; break;
+        res = RESOLVE_SCM_EXACT; break;
 
     case GH_TYPE_UNDEFINED:
-        pzRes = (char*)zNil; break;
+        res = (char*)zNil; break;
 
     default:
-        pzRes = RESOLVE_SCM_UNKNOWN; break;
+        res = RESOLVE_SCM_UNKNOWN; break;
     }
 
-    return pzRes;
+    return res;
 }
 
 /**
@@ -138,7 +140,7 @@ eval_mac_expr(bool * allocated)
 {
     templ_t *     tpl   = current_tpl;
     macro_t *     mac   = cur_macro;
-    int           code  = mac->md_res;
+    int           code  = (int)mac->md_res;
     char const *  text  = NULL; /* warning patrol */
     def_ent_t *   ent;
 
@@ -362,7 +364,7 @@ ag_scm_emit(SCM val)
     case 0:
         fp = cur_fpstack->stk_fp; // initialize the first time through
         break;
-    } 
+    }
 
     depth++;
     for (;;) {
@@ -453,7 +455,7 @@ eval(char const * expr)
 /*=macfunc EXPR
  *
  *  what:  Evaluate and emit an Expression
- *  alias: + - + ? + % + ; + ( + '`' + '"' + "'" + . +
+ *  alias: + - + ? + % + ; + ( + '`' + '"' + "'" + . + { +
  *
  *  handler_proc:
  *  load_proc:
@@ -525,7 +527,7 @@ mLoad_Expr(templ_t * tpl, macro_t * mac, char const ** ppzScan)
 {
     char *        copy; /* next text dest   */
     char const *  src     = (char const*)mac->md_txt_off; /* macro text */
-    size_t        src_len = (long)mac->md_res;           /* macro len  */
+    size_t        src_len = (size_t)mac->md_res;          /* macro len  */
     char const *  end_src = src + src_len;
 
     if (src_len == 0) {
@@ -562,6 +564,11 @@ mLoad_Expr(templ_t * tpl, macro_t * mac, char const ** ppzScan)
         span_quote(tpl->td_text + mac->md_txt_off);
         return mac + 1;
 
+    case '{':
+        (void) mLoad_Unknown(tpl, mac, ppzScan);
+        mac->md_res = EMIT_NO_DEFINE | EMIT_SHELL;
+        return mac + 1;
+
     case '"':
     case '\'':
         (void) mLoad_Unknown(tpl, mac, ppzScan);
@@ -581,9 +588,9 @@ mLoad_Expr(templ_t * tpl, macro_t * mac, char const ** ppzScan)
     }
 
     copy = tpl->td_scan;
-    mac->md_name_off = (copy - tpl->td_text);
+    mac->md_name_off = (uintptr_t)(copy - tpl->td_text);
     {
-        size_t remLen = canonical_name(copy, src, (int)src_len);
+        size_t remLen = (size_t)canonical_name(copy, src, (int)src_len);
         if (remLen > src_len)
             AG_ABEND_IN(tpl, mac, LD_EXPR_BAD_NAME);
         src    += src_len - remLen;
@@ -599,9 +606,9 @@ mLoad_Expr(templ_t * tpl, macro_t * mac, char const ** ppzScan)
 
     } else {
         char* pz = copy;
-        src_len = (long)(end_src - src);
+        src_len = (size_t)(end_src - src);
 
-        mac->md_txt_off = (copy - tpl->td_text);
+        mac->md_txt_off = (uintptr_t)(copy - tpl->td_text);
         /*
          *  Copy the expression
          */
@@ -632,17 +639,20 @@ mLoad_Expr(templ_t * tpl, macro_t * mac, char const ** ppzScan)
              */
             *(pzNextExpr++) = NUL;
             pzNextExpr = SPN_WHITESPACE_CHARS(pzNextExpr);
-            mac->md_res |= (expr_type(pzNextExpr) << EMIT_SECONDARY_SHIFT);
-            mac->md_end_idx = pzNextExpr - tpl->td_text;
+            mac->md_res |= (uintptr_t)(
+                (expr_type(pzNextExpr) << EMIT_SECONDARY_SHIFT));
+            mac->md_end_idx = (int)(pzNextExpr - tpl->td_text);
         }
 
-        mac->md_res |= expr_type(pz);
+        mac->md_res |= (uintptr_t)expr_type(pz);
     }
 
     tpl->td_scan = copy;
     return mac + 1;
 }
-/*
+/**
+ * @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
