@@ -2,11 +2,15 @@
 /**
  * \file file.c
  *
- *  Time-stamp:      "2011-08-06 08:49:35 bkorb"
+ * Handle options that have file names for arguments.
  *
+ * @addtogroup autoopts
+ * @{
+ */
+/*
  *  This file is part of AutoOpts, a companion to AutoGen.
  *  AutoOpts is free software.
- *  AutoOpts is Copyright (c) 1992-2011 by Bruce Korb - all rights reserved
+ *  AutoOpts is Copyright (C) 1992-2013 by Bruce Korb - all rights reserved
  *
  *  AutoOpts is available under any one of two licenses.  The license
  *  in use must be one of these two and the choice is under the control
@@ -18,11 +22,11 @@
  *   The Modified Berkeley Software Distribution License
  *      See the file "COPYING.mbsd"
  *
- *  These files have the following md5sums:
+ *  These files have the following sha256 sums:
  *
- *  43b91e8ca915626ed3818ffb1b71248b pkg/libopts/COPYING.gplv3
- *  06a1a2e4760c90ea5e1dad8dfaac4d39 pkg/libopts/COPYING.lgplv3
- *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
+ *  8584710e9b04216a394078dc156b781d0b47e1729104d666658aecef8ee32e95  COPYING.gplv3
+ *  4379e7444a0e2ce2b12dd6f5a52a27a4d02d39d247901d3285c88cf0d37f477b  COPYING.lgplv3
+ *  13aa749a5b0a454917a944ed8fffc530b784f5ead522b1aacaf4ec8aa55a6239  COPYING.mbsd
  */
 
 /**
@@ -46,9 +50,7 @@ check_existence(teOptFileType ftype, tOptions * pOpts, tOptDesc * pOD)
         if ((stat(fname, &sb) == 0) || (errno != ENOENT)) {
             if (errno == 0)
                 errno = EINVAL;
-            fprintf(stderr, zFSOptError, errno, strerror(errno),
-                    zFSOptErrNoExist, fname, pOD->pz_Name);
-            pOpts->pUsageProc(pOpts, EXIT_FAILURE);
+            fserr_exit(pOpts->pzProgName, "stat", fname);
             /* NOTREACHED */
         }
         /* FALLTHROUGH */
@@ -66,30 +68,25 @@ check_existence(teOptFileType ftype, tOptions * pOpts, tOptDesc * pOD)
              */
             break;
 
-        l = p - fname;
+        l = (size_t)(p - fname);
         p = AGALOC(l + 1, "fname");
         memcpy(p, fname, l);
         p[l] = NUL;
 
-        if ((stat(p, &sb) != 0) || (errno = EINVAL, ! S_ISDIR(sb.st_mode))) {
-            fprintf(stderr, zFSOptError, errno, strerror(errno),
-                    zFSOptErrMayExist, fname, pOD->pz_Name);
-            pOpts->pUsageProc(pOpts, EXIT_FAILURE);
+        if ((stat(p, &sb) != 0) || (errno = EINVAL, ! S_ISDIR(sb.st_mode)))
+            fserr_exit(pOpts->pzProgName, "stat", p);
             /* NOTREACHED */
-        }
+
         AGFREE(p);
         break;
     }
 
     case FTYPE_MODE_MUST_EXIST:
         if (  (stat(fname, &sb) != 0)
-           || (errno = EINVAL, ! S_ISREG(sb.st_mode)) ) {
-            fprintf(stderr, zFSOptError, errno, strerror(errno),
-                    zFSOptErrMustExist, fname,
-                    pOD->pz_Name);
-            pOpts->pUsageProc(pOpts, EXIT_FAILURE);
+           || (errno = EINVAL, ! S_ISREG(sb.st_mode))  )
+            fserr_exit(pOpts->pzProgName, "stat", fname);
             /* NOTREACHED */
-        }
+
         break;
     }
 }
@@ -105,12 +102,9 @@ static void
 open_file_fd(tOptions * pOpts, tOptDesc * pOD, tuFileMode mode)
 {
     int fd = open(pOD->optArg.argString, mode.file_flags);
-    if (fd < 0) {
-        fprintf(stderr, zFSOptError, errno, strerror(errno),
-                zFSOptErrOpen, pOD->optArg.argString, pOD->pz_Name);
-        pOpts->pUsageProc(pOpts, EXIT_FAILURE);
+    if (fd < 0)
+        fserr_exit(pOpts->pzProgName, "open", pOD->optArg.argString);
         /* NOTREACHED */
-    }
 
     if ((pOD->fOptState & OPTST_ALLOC_ARG) != 0)
         pOD->optCookie = (void *)pOD->optArg.argString;
@@ -131,13 +125,10 @@ open_file_fd(tOptions * pOpts, tOptDesc * pOD, tuFileMode mode)
 static void
 fopen_file_fp(tOptions * pOpts, tOptDesc * pOD, tuFileMode mode)
 {
-    FILE* fp = fopen(pOD->optArg.argString, mode.file_mode);
-    if (fp == NULL) {
-        fprintf(stderr, zFSOptError, errno, strerror(errno),
-                zFSOptErrFopen, pOD->optArg.argString, pOD->pz_Name);
-        pOpts->pUsageProc(pOpts, EXIT_FAILURE);
+    FILE * fp = fopen(pOD->optArg.argString, mode.file_mode);
+    if (fp == NULL)
+        fserr_exit(pOpts->pzProgName, "fopen", pOD->optArg.argString);
         /* NOTREACHED */
-    }
 
     if ((pOD->fOptState & OPTST_ALLOC_ARG) != 0)
         pOD->optCookie = (void *)pOD->optArg.argString;
@@ -174,11 +165,11 @@ optionFileCheck(tOptions * pOpts, tOptDesc * pOD,
 
         switch (ftype & FTYPE_MODE_EXIST_MASK) {
         case FTYPE_MODE_MUST_NOT_EXIST:
-            fputs(zFileCannotExist, option_usage_fp);
+            fputs(zFileCannotExist + tab_skip_ct, option_usage_fp);
             break;
 
         case FTYPE_MODE_MUST_EXIST:
-            fputs(zFileMustExist, option_usage_fp);
+            fputs(zFileMustExist + tab_skip_ct, option_usage_fp);
             break;
         }
         return;
@@ -199,7 +190,9 @@ optionFileCheck(tOptions * pOpts, tOptDesc * pOD,
     case FTYPE_MODE_FOPEN_FP: fopen_file_fp(pOpts, pOD, mode); break;
     }
 }
-/*
+
+/** @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
